@@ -5,7 +5,7 @@ use warnings;
 
 use Carp ();
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 our $PREFIX  = '__cag_';
 
 require XSLoader;
@@ -131,8 +131,7 @@ sub _mk_inherited_accessor {
 sub _mk_class_accessor {
     my ($class, $name, $default, $is_varclass, $is_readonly) = @_;
 
-    install_class_accessor("${class}::${name}", $is_varclass, $is_readonly);
-    ${\$class->$name} = $default if defined $default;
+    install_class_accessor("${class}::${name}", $default, $is_varclass, $is_readonly);
 }
 
 sub _mk_object_accessor {
@@ -160,7 +159,7 @@ Class::Accessor::Inherited::XS - Fast XS inherited, object and class accessors
   use Class::Accessor::Inherited::XS 
       package      => 'Pkg', # optionally install into another package
       constructor  => 'new', # object constructor name
-      inherited    => 'foo', # inherited accessor for classes/objects
+      inherited    => 'foo', # inherited accessor for class/object
       object       => 'foo', # non-inherited simple object accessor
       varclass     => 'foo', # non-inherited accessor for __PACKAGE__,  aliased with '$__PACKAGE__::foo' variable
       class        => 'foo', # non-inherited anonymous accessor for __PACKAGE__
@@ -169,8 +168,9 @@ Class::Accessor::Inherited::XS - Fast XS inherited, object and class accessors
   use Class::Accessor::Inherited::XS {  # optional braces
       inherited => {foo => 'foo_key'},  # change package variable/hash key
       object    => {foo => 'foo_key'},  # change hash key
-      class_ro  => {foo => $default},   # B<class_ro>, B<varclass_ro>, B<class>, B<varclass> set default values instead
-      class     => ['foo', 'bar'],      # provide a list of accessor names
+      class_ro  => {foo => $default},   # class_ro, varclass_ro, class, varclass set default values instead
+      class     => {foo => $subref},    # lazy accessor initializer
+      varclass  => ['foo', 'bar'],      # provide a list of accessor names
   };
 
   # or at run time, in a Class::Accessor::Grouped-like fashion
@@ -201,10 +201,16 @@ in an anonymous variable.
 
 B<object> accessors provides plain simple hash key access.
 
-There are following read-only accessor types: B<class_ro>, B<varclass_ro>, B<inherited_ro>, B<object_ro>.
-They behave exactly like theirs non-ro counterparts, but will croak when you try to call them with arguments.
-To set values for such accessors, you have to access either corresponding package variable or a hash key. But
-B<ro_class> accessor has none - so you can provide a default value for it using hash initializer syntax.
+B<class_ro>, B<varclass_ro>, B<inherited_ro>, B<object_ro> are readonly counterparts for correspoding accessors
+without B<_ro> suffix. They behave exactly the same except that they will croak upon a call with arguments.
+To set values for such accessors, you can write to either corresponding package variable or a hash key. B<ro_class>
+accessor has no externally accessible storage, but you can provide a default value for it using hash
+initializer syntax.
+
+B<lazy> accessors do not have their own keyword but, instead, if you pass a subref as a B<default> argument
+to any one of the B<class> accessors' family, it's not stored as-is, but is called instead upon the first accessor
+read and it's return value is stored. After that, B<lazy> accessor becomes a normal one of the same type. Calling
+an accessor as a setter before first getter will loose it's defaultness (unless, of course, it's a readonly one).
 
 B<constructor> can create objects either from a list or from a single hashref. Note that if you pass
 a hash reference, it becomes blessed too. If that's not what you want, pass a dereferenced copy.
@@ -275,13 +281,13 @@ class_caix       34345065/s          13328%   3044%   2337%             910%
 You can register new inherited accessor types with associated read/write callbacks. Unlike
 L<Class::Accessor::Grouped>, only a single callback can be set for a type, without per-class
 B<get_$type>/B<set_$type> lookups. You can omit either B<on_read> or B<on_write> if you don't
-need them to avoid performance losses.
+need it to avoid performance losses from associated call.
 
 B<on_read> callback receives a single argument - return value from the underlying B<inherited> accessor. It's result
 is the new accessor's return value (and it isn't stored anywhere).
 
 B<on_write> callback receives original accessor's arguments, and it's return value is stored as usual.
-Exceptions thrown from this callback will cancel store and will leave the old value unchanged.
+Exceptions thrown from this callback will cancel store and will leave old value unchanged.
 
 =head1 PROFILING WITH Devel::NYTProf
 
